@@ -3,4 +3,4 @@ import torch  # noqa
 import pandas  # noqa
 import arraydebug  # noqa
 
-arraydebug.register_reprs()
+arraydebug.enable()
